pub enum ReadbackTemplate {
Texture(<Handle<Image> as FromTemplate>::Template),
Buffer {
buffer: <Handle<ShaderBuffer> as FromTemplate>::Template,
start_offset_and_size: <Option<(u64, u64)> as FromTemplate>::Template,
},
}Variants
Texture(<Handle<Image> as FromTemplate>::Template)
Buffer
Fields

buffer: <Handle<ShaderBuffer> as FromTemplate>::TemplateImplementations
Sourceimpl ReadbackTemplate
impl ReadbackTemplate
Sourcepub fn default_texture() -> ReadbackTemplate
pub fn default_texture() -> ReadbackTemplate
Default value for this variant, generated by a FromTemplate derive.
Sourcepub fn default_buffer() -> ReadbackTemplate
pub fn default_buffer() -> ReadbackTemplate
Default value for this variant, generated by a FromTemplate derive.